# Change log

## `v3.0.0` - 2023-10-04

### Dependencies
- Add support for `aiida-core~=2.0` [[7b19989]](https://github.com/aiidaplugins/aiida-ase/commit/7b19989b3dc8219da7ab47f10f91c70cf8ba94b1)
- Add support for Python 3.11 [[0f354b4]](https://github.com/aiidaplugins/aiida-ase/commit/0f354b4e169a223f3ee2e7e11a42a76d3a0e6ae5)
- Drop support for Python 3.7 [[df3f5c3]](https://github.com/aiidaplugins/aiida-ase/commit/df3f5c39e491ef70ff356a5d3c30b41b9345b643)

### Devops
- Use caching of `setup-python` action [[89ff857]](https://github.com/aiidaplugins/aiida-ase/commit/89ff8571653e56f68d81a67f33dac7adce105499)


## `v2.0.0` - 2023-03-17

This version is compatible with `aiida-core~=1.0`.
